==> dcmtk-docs-3.6.9-3-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/enumvalues_c.js <==
var searchData=
[
  ['lactate_0',['Lactate',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2abab8366ed19b4a36098e62b7017ddaef',1,'CID218_QuantitativeImageFeature::Lactate'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a68e23c42179b3e2da71792f56eabff67',1,'CID7469_GenericIntensityAndSizeMeasurement::Lactate']]],
  ['largedistanceemphasis_1',['LargeDistanceEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae4299f7c274ba5cac10cc04530d009d2',1,'CID218_QuantitativeImageFeature']]],
  ['largedistancehighgreylevelemphasis_2',['LargeDistanceHighGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a6ace7a40266f0020877babcdc5419789',1,'CID218_QuantitativeImageFeature']]],
  ['largedistancelowgreylevelemphasis_3',['LargeDistanceLowGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a75da35433bb1c76ceb503426e61f0cd1',1,'CID218_QuantitativeImageFeature']]],
  ['largeintestine_4',['LargeIntestine',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a7aea9ffe53107c636576c7723b4a56ae',1,'CID4031_CommonAnatomicRegion']]],
  ['largezoneemphasis_5',['LargeZoneEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a383df4603668903be44b7cb66afb554c',1,'CID218_QuantitativeImageFeature']]],
  ['largezonehighgraylevelemphasis_6',['LargeZoneHighGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae46e771e4bb1569360db1859fedcad8a',1,'CID218_QuantitativeImageFeature']]],
  ['largezonelowgraylevelemphasis_7',['LargeZoneLowGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2aabf675f790354111aa49824021ef0937',1,'CID218_QuantitativeImageFeature']]],
  ['larynx_8',['Larynx',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a40e7f602c235e445af744e115b7d8dd4',1,'CID4031_CommonAnatomicRegion']]],
  ['laserscan_9',['LaserScan',['../classCID29__AcquisitionModality.html#a923e8bade806fc79e69fbb9ed91e5dc4a03230c3debcbd563a5aa96319590b51a',1,'CID29_AcquisitionModality']]],
  ['lat_5ferror_10',['LAT_ERROR',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554ebab40d02b25cf2128426e766c21de86934',1,'TrcTypes']]],
  ['lat_5fleft_11',['LAT_LEFT',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554ebad953465f1c728dfe2273fa0444773616',1,'TrcTypes']]],
  ['lat_5fright_12',['LAT_RIGHT',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554eba7a3390ab6c472a98d61ade2b8cca8310',1,'TrcTypes']]],
  ['lat_5fright_5fand_5fleft_13',['LAT_RIGHT_AND_LEFT',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554eba49ec9f905be8c18302a9a9d1dae8245d',1,'TrcTypes']]],
  ['lat_5funilateral_14',['LAT_UNILATERAL',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554ebaf220f2193c8695555a404a8897928fbb',1,'TrcTypes']]],
  ['lat_5funknown_15',['LAT_UNKNOWN',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554eba661db54ffeed2a8abc38fb0b81b03bde',1,'TrcTypes']]],
  ['laterality_5fboth_16',['LATERALITY_BOTH',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda8a4b5d669720ba34fcce45dfe0035c16',1,'FGFrameAnatomy']]],
  ['laterality_5finvalid_17',['LATERALITY_INVALID',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28ddacb51308a41470d5c26e6f53c2965f403',1,'FGFrameAnatomy']]],
  ['laterality_5fl_18',['LATERALITY_L',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda6fc95e56c60b40d840ec99aee0f5660f',1,'FGFrameAnatomy::LATERALITY_L'],['../classDcmIODTypes.html#ab4f24ae19083d68371a0b8b8b353dcf4ad3b3034581d790c9e28edbbb6ff06888',1,'DcmIODTypes::LATERALITY_L']]],
  ['laterality_5fr_19',['LATERALITY_R',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28ddab6064f43a2e95a98e48f6f992a7e6fb8',1,'FGFrameAnatomy::LATERALITY_R'],['../classDcmIODTypes.html#ab4f24ae19083d68371a0b8b8b353dcf4a8eafdfd2787c671162e5fb7035b7fb92',1,'DcmIODTypes::LATERALITY_R']]],
  ['laterality_5fundefined_20',['LATERALITY_UNDEFINED',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda4745c0db820b2e88987a820de2e1a1d6',1,'FGFrameAnatomy::LATERALITY_UNDEFINED'],['../classDcmIODTypes.html#ab4f24ae19083d68371a0b8b8b353dcf4a49ce76b1bb93de6dc7979c6f93b8e13d',1,'DcmIODTypes::LATERALITY_UNDEFINED']]],
  ['laterality_5funpaired_21',['LATERALITY_UNPAIRED',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda997dd1646d278b5159897671e33fd972',1,'FGFrameAnatomy']]],
  ['leadradiologictechnologist_22',['LeadRadiologicTechnologist',['../classCID7452__OrganizationalRole.html#ae3343fb7d88179f020e13d407f1b9376ad5017f05a616d28ee4174311b861fd3d',1,'CID7452_OrganizationalRole']]],
  ['leastaxisin3dlength_23',['LeastAxisIn3DLength',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a4984c72f9dd9f31223ca77d8e596d799',1,'CID218_QuantitativeImageFeature::LeastAxisIn3DLength'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a5f491ce4ff58498b57f25d7e0fcb8688',1,'CID7469_GenericIntensityAndSizeMeasurement::LeastAxisIn3DLength']]],
  ['left_24',['Left',['../classCID244__Laterality.html#a346e51a79516c88a58d45c6307411adca66391c9c4372b32204fdd578f2883d00',1,'CID244_Laterality::Left'],['../classCID247__LateralityLeftRightOnly.html#a69b0d77d1c0ae939de89b0e44242dc88a4c7f40b300b91386e217087e1e28c6b1',1,'CID247_LateralityLeftRightOnly::Left']]],
  ['length_25',['Length',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ac691e2b10f7d9999cad3ab9b661d4b99',1,'CID218_QuantitativeImageFeature::Length'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a29717c252ba171e6656e894abeb5281c',1,'CID7469_GenericIntensityAndSizeMeasurement::Length']]],
  ['lensometry_26',['Lensometry',['../classCID29__AcquisitionModality.html#a923e8bade806fc79e69fbb9ed91e5dc4ae754cdee9eeadb465adc56a0aca3a50c',1,'CID29_AcquisitionModality']]],
  ['level_5finstance_27',['LEVEL_INSTANCE',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173a95a6e27a5753341b6c2aa3c337523b3e',1,'IODReference']]],
  ['level_5fpatient_28',['LEVEL_PATIENT',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173a2942375f2bb04d7278434a2dfbcd848d',1,'IODReference']]],
  ['level_5fseries_29',['LEVEL_SERIES',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173aebd189603e31710e6f5a06f2e937df50',1,'IODReference']]],
  ['level_5fstudy_30',['LEVEL_STUDY',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173ace18256b1649a03f2104238062264065',1,'IODReference']]],
  ['linesegmentlength_31',['LineSegmentLength',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a32aa340d503d94884a3de38cf3aab0a0',1,'CID218_QuantitativeImageFeature::LineSegmentLength'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39abe8c5aa301a6ca678ed508833f831551',1,'CID7469_GenericIntensityAndSizeMeasurement::LineSegmentLength']]],
  ['lipid_32',['Lipid',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae9de3e68e38e71e203a2b030e9fa43b8',1,'CID218_QuantitativeImageFeature::Lipid'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a74a4cdd7e2bcf5710ef2187fd3cfdfc6',1,'CID7469_GenericIntensityAndSizeMeasurement::Lipid']]],
  ['lipidandlactate_33',['LipidAndLactate',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a3d05d1ea4ac9c9d1c68b7bdd79faedfd',1,'CID218_QuantitativeImageFeature::LipidAndLactate'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39af50150e5360b679e8141f26f5e1f9d3b',1,'CID7469_GenericIntensityAndSizeMeasurement::LipidAndLactate']]],
  ['listen_34',['LISTEN',['../classDcmBaseSCPPool.html#adb7f57f4954226c1fa1bf391acc5d138aeb34332dccb728d8133d1203b2cab71b',1,'DcmBaseSCPPool']]],
  ['liverandbiliarystructure_35',['LiverAndBiliaryStructure',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0ac56b2cbc384b5f4a506875115002e3cc',1,'CID4031_CommonAnatomicRegion']]],
  ['longaxis_36',['LongAxis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2af734f6b995bbd5b05c920f3a9b2add71',1,'CID218_QuantitativeImageFeature::LongAxis'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a2479c43098b44cc5b18e6429e5ee1183',1,'CID7469_GenericIntensityAndSizeMeasurement::LongAxis']]],
  ['longrunhighgraylevelemphasis_37',['LongRunHighGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a20164b96f402a163e26e85b1859fd7bf',1,'CID218_QuantitativeImageFeature']]],
  ['longrunlowgraylevelemphasis_38',['LongRunLowGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a8516d839909b48d9815ea5817822d47c',1,'CID218_QuantitativeImageFeature']]],
  ['longrunsemphasis_39',['LongRunsEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a7c93b2d6c3a41ef3fe6feddd3261979b',1,'CID218_QuantitativeImageFeature']]],
  ['lowdependenceemphasis_40',['LowDependenceEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a5995419bfed2b619408c95aa1d65513b',1,'CID218_QuantitativeImageFeature']]],
  ['lowdependencehighgreylevelemphasis_41',['LowDependenceHighGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a2cb0bdae727fc7903db68d4bb473dd8f',1,'CID218_QuantitativeImageFeature']]],
  ['lowdependencelowgreylevelemphasis_42',['LowDependenceLowGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a4d7a30e4aa43673a3f865d4e43fde362',1,'CID218_QuantitativeImageFeature']]],
  ['lowerleg_43',['LowerLeg',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0ad945290209fe7ddb6f32e72e53428720',1,'CID4031_CommonAnatomicRegion']]],
  ['lowerlimb_44',['LowerLimb',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a6c9acde1ac28109d639e150d76c03042',1,'CID4031_CommonAnatomicRegion']]],
  ['lowgraylevelrunemphasis_45',['LowGrayLevelRunEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a9787a2cdb8d883bc96879d4289109f77',1,'CID218_QuantitativeImageFeature']]],
  ['lowgraylevelzoneemphasis_46',['LowGrayLevelZoneEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2aa547ba2d2f806ae09dcc9019fc1ac1a3',1,'CID218_QuantitativeImageFeature']]],
  ['lowgreylevelcountemphasis_47',['LowGreyLevelCountEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a9723a9efb9e72d1ddfc58b6e6e16c598',1,'CID218_QuantitativeImageFeature']]],
  ['lowgreylevelzoneemphasis_48',['LowGreyLevelZoneEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a182674ba657229386f467dc31801dbb1',1,'CID218_QuantitativeImageFeature']]],
  ['lumbarspine_49',['LumbarSpine',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a2b90451403e86dc2e7acb1abe8fc62e3',1,'CID4031_CommonAnatomicRegion']]],
  ['lumbosacralspine_50',['LumboSacralSpine',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a1b2e962f77eb981feac219d83965a797',1,'CID4031_CommonAnatomicRegion']]]
];

==> dcmtk-docs-3.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/enumvalues_c.js <==
var searchData=
[
  ['lactate_0',['Lactate',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2abab8366ed19b4a36098e62b7017ddaef',1,'CID218_QuantitativeImageFeature::Lactate'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a68e23c42179b3e2da71792f56eabff67',1,'CID7469_GenericIntensityAndSizeMeasurement::Lactate']]],
  ['largedistanceemphasis_1',['LargeDistanceEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae4299f7c274ba5cac10cc04530d009d2',1,'CID218_QuantitativeImageFeature']]],
  ['largedistancehighgreylevelemphasis_2',['LargeDistanceHighGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a6ace7a40266f0020877babcdc5419789',1,'CID218_QuantitativeImageFeature']]],
  ['largedistancelowgreylevelemphasis_3',['LargeDistanceLowGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a75da35433bb1c76ceb503426e61f0cd1',1,'CID218_QuantitativeImageFeature']]],
  ['largeintestine_4',['LargeIntestine',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a7aea9ffe53107c636576c7723b4a56ae',1,'CID4031_CommonAnatomicRegion']]],
  ['largezoneemphasis_5',['LargeZoneEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a383df4603668903be44b7cb66afb554c',1,'CID218_QuantitativeImageFeature']]],
  ['largezonehighgraylevelemphasis_6',['LargeZoneHighGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae46e771e4bb1569360db1859fedcad8a',1,'CID218_QuantitativeImageFeature']]],
  ['largezonelowgraylevelemphasis_7',['LargeZoneLowGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2aabf675f790354111aa49824021ef0937',1,'CID218_QuantitativeImageFeature']]],
  ['larynx_8',['Larynx',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a40e7f602c235e445af744e115b7d8dd4',1,'CID4031_CommonAnatomicRegion']]],
  ['lasersurfacescan_9',['LaserSurfaceScan',['../classCID29__AcquisitionModality.html#a923e8bade806fc79e69fbb9ed91e5dc4a70fa0b00bd8df41805d46eab612ed56d',1,'CID29_AcquisitionModality']]],
  ['lat_5ferror_10',['LAT_ERROR',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554ebab40d02b25cf2128426e766c21de86934',1,'TrcTypes']]],
  ['lat_5fleft_11',['LAT_LEFT',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554ebad953465f1c728dfe2273fa0444773616',1,'TrcTypes']]],
  ['lat_5fright_12',['LAT_RIGHT',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554eba7a3390ab6c472a98d61ade2b8cca8310',1,'TrcTypes']]],
  ['lat_5fright_5fand_5fleft_13',['LAT_RIGHT_AND_LEFT',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554eba49ec9f905be8c18302a9a9d1dae8245d',1,'TrcTypes']]],
  ['lat_5funilateral_14',['LAT_UNILATERAL',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554ebaf220f2193c8695555a404a8897928fbb',1,'TrcTypes']]],
  ['lat_5funknown_15',['LAT_UNKNOWN',['../classTrcTypes.html#ab9ef0ad41588043e9dc2de2afaf554eba661db54ffeed2a8abc38fb0b81b03bde',1,'TrcTypes']]],
  ['laterality_5fboth_16',['LATERALITY_BOTH',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda8a4b5d669720ba34fcce45dfe0035c16',1,'FGFrameAnatomy']]],
  ['laterality_5finvalid_17',['LATERALITY_INVALID',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28ddacb51308a41470d5c26e6f53c2965f403',1,'FGFrameAnatomy']]],
  ['laterality_5fl_18',['LATERALITY_L',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda6fc95e56c60b40d840ec99aee0f5660f',1,'FGFrameAnatomy::LATERALITY_L'],['../classDcmIODTypes.html#ab4f24ae19083d68371a0b8b8b353dcf4ad3b3034581d790c9e28edbbb6ff06888',1,'DcmIODTypes::LATERALITY_L']]],
  ['laterality_5fr_19',['LATERALITY_R',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28ddab6064f43a2e95a98e48f6f992a7e6fb8',1,'FGFrameAnatomy::LATERALITY_R'],['../classDcmIODTypes.html#ab4f24ae19083d68371a0b8b8b353dcf4a8eafdfd2787c671162e5fb7035b7fb92',1,'DcmIODTypes::LATERALITY_R']]],
  ['laterality_5fundefined_20',['LATERALITY_UNDEFINED',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda4745c0db820b2e88987a820de2e1a1d6',1,'FGFrameAnatomy::LATERALITY_UNDEFINED'],['../classDcmIODTypes.html#ab4f24ae19083d68371a0b8b8b353dcf4a49ce76b1bb93de6dc7979c6f93b8e13d',1,'DcmIODTypes::LATERALITY_UNDEFINED']]],
  ['laterality_5funpaired_21',['LATERALITY_UNPAIRED',['../classFGFrameAnatomy.html#abcc4f8001cd9cc16f3cf9aa9102a28dda997dd1646d278b5159897671e33fd972',1,'FGFrameAnatomy']]],
  ['leadradiologictechnologist_22',['LeadRadiologicTechnologist',['../classCID7452__OrganizationalRole.html#ae3343fb7d88179f020e13d407f1b9376ad5017f05a616d28ee4174311b861fd3d',1,'CID7452_OrganizationalRole']]],
  ['leastaxisin3dlength_23',['LeastAxisIn3DLength',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a4984c72f9dd9f31223ca77d8e596d799',1,'CID218_QuantitativeImageFeature::LeastAxisIn3DLength'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a5f491ce4ff58498b57f25d7e0fcb8688',1,'CID7469_GenericIntensityAndSizeMeasurement::LeastAxisIn3DLength']]],
  ['left_24',['Left',['../classCID244__Laterality.html#a346e51a79516c88a58d45c6307411adca66391c9c4372b32204fdd578f2883d00',1,'CID244_Laterality::Left'],['../classCID247__LateralityLeftRightOnly.html#a69b0d77d1c0ae939de89b0e44242dc88a4c7f40b300b91386e217087e1e28c6b1',1,'CID247_LateralityLeftRightOnly::Left']]],
  ['length_25',['Length',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ac691e2b10f7d9999cad3ab9b661d4b99',1,'CID218_QuantitativeImageFeature::Length'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a29717c252ba171e6656e894abeb5281c',1,'CID7469_GenericIntensityAndSizeMeasurement::Length']]],
  ['lensometry_26',['Lensometry',['../classCID29__AcquisitionModality.html#a923e8bade806fc79e69fbb9ed91e5dc4ae754cdee9eeadb465adc56a0aca3a50c',1,'CID29_AcquisitionModality']]],
  ['level_5finstance_27',['LEVEL_INSTANCE',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173a95a6e27a5753341b6c2aa3c337523b3e',1,'IODReference']]],
  ['level_5fpatient_28',['LEVEL_PATIENT',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173a2942375f2bb04d7278434a2dfbcd848d',1,'IODReference']]],
  ['level_5fseries_29',['LEVEL_SERIES',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173aebd189603e31710e6f5a06f2e937df50',1,'IODReference']]],
  ['level_5fstudy_30',['LEVEL_STUDY',['../classIODReference.html#ad32ee022af46abea58c5d191f679a173ace18256b1649a03f2104238062264065',1,'IODReference']]],
  ['linesegmentlength_31',['LineSegmentLength',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a32aa340d503d94884a3de38cf3aab0a0',1,'CID218_QuantitativeImageFeature::LineSegmentLength'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39abe8c5aa301a6ca678ed508833f831551',1,'CID7469_GenericIntensityAndSizeMeasurement::LineSegmentLength']]],
  ['lipid_32',['Lipid',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae9de3e68e38e71e203a2b030e9fa43b8',1,'CID218_QuantitativeImageFeature::Lipid'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a74a4cdd7e2bcf5710ef2187fd3cfdfc6',1,'CID7469_GenericIntensityAndSizeMeasurement::Lipid']]],
  ['lipidandlactate_33',['LipidAndLactate',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a3d05d1ea4ac9c9d1c68b7bdd79faedfd',1,'CID218_QuantitativeImageFeature::LipidAndLactate'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39af50150e5360b679e8141f26f5e1f9d3b',1,'CID7469_GenericIntensityAndSizeMeasurement::LipidAndLactate']]],
  ['listen_34',['LISTEN',['../classDcmBaseSCPPool.html#adb7f57f4954226c1fa1bf391acc5d138aeb34332dccb728d8133d1203b2cab71b',1,'DcmBaseSCPPool']]],
  ['liverandbiliarystructure_35',['LiverAndBiliaryStructure',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0ac56b2cbc384b5f4a506875115002e3cc',1,'CID4031_CommonAnatomicRegion']]],
  ['longaxis_36',['LongAxis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2af734f6b995bbd5b05c920f3a9b2add71',1,'CID218_QuantitativeImageFeature::LongAxis'],['../classCID7469__GenericIntensityAndSizeMeasurement.html#ad6fa23fbb5e6a9108981959c9fd03d39a2479c43098b44cc5b18e6429e5ee1183',1,'CID7469_GenericIntensityAndSizeMeasurement::LongAxis']]],
  ['longrunhighgraylevelemphasis_37',['LongRunHighGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a20164b96f402a163e26e85b1859fd7bf',1,'CID218_QuantitativeImageFeature']]],
  ['longrunlowgraylevelemphasis_38',['LongRunLowGrayLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a8516d839909b48d9815ea5817822d47c',1,'CID218_QuantitativeImageFeature']]],
  ['longrunsemphasis_39',['LongRunsEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a7c93b2d6c3a41ef3fe6feddd3261979b',1,'CID218_QuantitativeImageFeature']]],
  ['lowdependenceemphasis_40',['LowDependenceEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a5995419bfed2b619408c95aa1d65513b',1,'CID218_QuantitativeImageFeature']]],
  ['lowdependencehighgreylevelemphasis_41',['LowDependenceHighGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a2cb0bdae727fc7903db68d4bb473dd8f',1,'CID218_QuantitativeImageFeature']]],
  ['lowdependencelowgreylevelemphasis_42',['LowDependenceLowGreyLevelEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a4d7a30e4aa43673a3f865d4e43fde362',1,'CID218_QuantitativeImageFeature']]],
  ['lowerleg_43',['LowerLeg',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0ad945290209fe7ddb6f32e72e53428720',1,'CID4031_CommonAnatomicRegion']]],
  ['lowerlimb_44',['LowerLimb',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a6c9acde1ac28109d639e150d76c03042',1,'CID4031_CommonAnatomicRegion']]],
  ['lowertrunk_45',['LowerTrunk',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0af5bbdd1491a663f496e402355c8c9172',1,'CID4031_CommonAnatomicRegion']]],
  ['lowgraylevelrunemphasis_46',['LowGrayLevelRunEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a9787a2cdb8d883bc96879d4289109f77',1,'CID218_QuantitativeImageFeature']]],
  ['lowgraylevelzoneemphasis_47',['LowGrayLevelZoneEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2aa547ba2d2f806ae09dcc9019fc1ac1a3',1,'CID218_QuantitativeImageFeature']]],
  ['lowgreylevelcountemphasis_48',['LowGreyLevelCountEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a9723a9efb9e72d1ddfc58b6e6e16c598',1,'CID218_QuantitativeImageFeature']]],
  ['lowgreylevelzoneemphasis_49',['LowGreyLevelZoneEmphasis',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a182674ba657229386f467dc31801dbb1',1,'CID218_QuantitativeImageFeature']]],
  ['lumbarspine_50',['LumbarSpine',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a2b90451403e86dc2e7acb1abe8fc62e3',1,'CID4031_CommonAnatomicRegion']]],
  ['lumbosacralspine_51',['LumboSacralSpine',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a1b2e962f77eb981feac219d83965a797',1,'CID4031_CommonAnatomicRegion']]]
];
